//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenResult](index.md)/[shantenInfo](shanten-info.md)

# shantenInfo

[common]\
open override val [shantenInfo](shanten-info.md): [ShantenWithFuroChance](../-shanten-with-furo-chance/index.md)

向听信息
